==> qtjambi-designer-debuginfo-macos-5.15.17.jar: sources/QtJambiDesigner/QDesignerMetaDataBaseInterface_shell.h <==
#ifndef QDESIGNERMETADATABASEINTERFACE_SHELL_H
#define QDESIGNERMETADATABASEINTERFACE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtDesigner/abstractmetadatabase.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtDesigner/abstractformeditor.h>
#include <QtJambi/RegistryAPI>


class QDesignerMetaDataBaseInterface_shell : public QDesignerMetaDataBaseInterface, public QtJambiShellInterface
{
public:
    QDesignerMetaDataBaseInterface_shell(QObject* parent0 = nullptr);
    ~QDesignerMetaDataBaseInterface_shell() override;

    void add(QObject* object0) override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    QDesignerFormEditorInterface* core() const override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QDesignerMetaDataBaseItemInterface* item(QObject* object0) const override;
    QList<QObject*> objects() const override;
    void remove(QObject* object0) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QDesignerMetaDataBaseInterface_access : public QDesignerMetaDataBaseInterface
{
    void __qt_add_QObject_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID object0);
    jobject __qt_core(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_item_QObject_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID object0) const;
    jobject __qt_objects(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_remove_QObject_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID object0);
};

#endif // QDESIGNERMETADATABASEINTERFACE_SHELL_H

==> qtjambi-designer-debuginfo-macos-6.5.3.jar: sources/QtJambiDesigner/QDesignerMetaDataBaseInterface_shell.h <==
#ifndef QDESIGNERMETADATABASEINTERFACE_SHELL_H
#define QDESIGNERMETADATABASEINTERFACE_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtDesigner/abstractmetadatabase.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtDesigner/abstractformeditor.h>
#include <QtJambi/RegistryAPI>


class QDesignerMetaDataBaseInterface_shell : public QDesignerMetaDataBaseInterface, public QtJambiShellInterface
{
public:
    QDesignerMetaDataBaseInterface_shell(QObject* parent0 = nullptr);
    ~QDesignerMetaDataBaseInterface_shell() override;

    void add(QObject* object0) override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    QDesignerFormEditorInterface* core() const override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QDesignerMetaDataBaseItemInterface* item(QObject* object0) const override;
    QList<QObject*> objects() const override;
    void remove(QObject* object0) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QDesignerMetaDataBaseInterface_access : public QDesignerMetaDataBaseInterface
{
    void __qt_add_QObject_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID object0);
    jobject __qt_core(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jobject __qt_item_QObject_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID object0) const;
    jobject __qt_objects(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_remove_QObject_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID object0);
};

#endif // QDESIGNERMETADATABASEINTERFACE_SHELL_H
